package provide windows 1.18
#
proc install {argv} {
    global Type types Lib Bin CC LD Version Patchlevel Wish types cflags\
      libs share SCflag GCC SLDflag CFlags TIDir NoGUI
#
    package require support
    package require -exact unixfile
#
    switch -glob -- [info tclversion] 7.* {
        tk_dialog .wdz {Windows Installation} {Sorry, you  must have tcl/tk version\
	8.0p2 or later to install under WIndows 95 or NT.} info 0 OK
	exit 1
    }
#
    set argv [doGlobals $argv]
#
    set w [mainWindow]
    set i 0
#
# Zircon library directory
#
    makeEntry $w lib {Library Directory} Lib [incr i] getLib
#
# Zircon binary directory
#
    makeEntry $w bin {Binary Directory} Bin [incr i] getBin
#
# Wish
#
    makeEntry $w wish {Tcl/Tk Interpreter} Wish [incr i] getWish
#
# Info
#
    if !{$NoGUI} {
	grid [frame $w.sep2 -bg red] - -sticky ew -pady 2
	grid [label $w.info] -columnspan 2 -sticky ew
    }
    if {$go} { Go ; Quit }
#
# Buttons
#
    if {!$NoGUI} {
	grid [frame $w.sep3 -bg red] - -sticky ew -pady 2
	frame $w.btn
	button $w.btn.quit -text Quit -command Quit -width 12
	button $w.btn.install -text Install -command Go -width 12
	grid $w.btn.quit $w.btn.install
	grid $w.btn -columnspan 2 -sticky ew
    }
}
#
proc makeLibrary {} {
    global Lib Manifest Index Patchlevel Version TIDir
    switch {} $TIDir {} default {
	if {![file exists [set TIDir [fixPath $TIDir]]]} {
	    fail "Directory \"$TIDir\" does not exist"
	    return 0
	}
	if {![file isdirectory $TIDir]} {
	    fail "\"$TIDir\" is not a directory"
	    return 0
	}
	if {![file exists [file join $TIDir tcl.h]]} {
	    fail "tcl.h does not exist in \"$TIDir\""
	    return 0
	}
    }
    if {[file exists [set Lib [fixPath $Lib]]]} {
	if {[file exists [set fn [file join $Lib installed]]]} {
	    set fd [open $fn r]
	    gets $fd line
	    close $fd
	    set ov [lindex $line 0]
	    set op [lindex $line 1]
	    set ext -$Version$Patchlevel
	    switch $ov $Version {
		switch $op $Patchlevel {
		   if {[askUser {Same Version} "You are installing version\
$Version $Patchlevel again.

Overwrite the existing version?"]} { set ext {} }
		}
	    }
	} {
	    set ext .old
	}
	switch {} $ext {} default {
	    if {[catch {filerename $Lib $Lib$ext} msg]} {
		if {![askUser Continue "Cannot rename $Lib to \
		  $Lib.old - \"$msg\"

Continue?"]} { return 0 }
	    }
	    if {[catch {filemkdir $Lib} msg]} {
		fail "Cannot make directory $Lib - \"$msg\""
		return 0
	    }
	}
    } \
    elseif {[catch {filemkdir $Lib} msg]} {
	fail "Cannot make directory $Lib - \"$msg\""
	return 0
    }
    foreach x [lsort [array names Manifest]] { 
	switch {} $Manifest($x) {} default {$Manifest($x) $x $Lib }
    }
    foreach x $Index {
	zinfo "Making package index for $x..."
	if {[catch {pkg_mkIndex [file join $Lib $x] *.tcl \
	  *[info sharedlibextension]} msg]} {
	    fail "Error whilst making package index for $x - \"$msg\""
	    return 0
	}
    }
    set fd [open [file join $Lib installed] a]
    puts $fd "$Version $Patchlevel {[clock format [clock seconds]]}"
    close $fd
    return 1}
#
proc makeBinary {} {
    zinfo "Making zircon..."
    global Bin Lib Version Patchlevel Wish
    if {![file exists [set Bin [fixPath $Bin]]]} {
	if {[catch {filemkdir $Bin} msg]} {
	    fail "Cannot create directory \"$Bin\" - $msg"
	    return 0
	}
    } \
    elseif {![file isdirectory $Bin]} {
	fail "\"$Bin\" is not a directory"
	return 0
    }
    set tf [file join $Bin zircon]
    if {[file exists $tf]} {
	if {[catch {filerename $tf $tf.old} msg]} {
	   fail "Cannot rename previous zircon executable - \"$msg\""
	   return 0
	}
    }
    if {[catch {open $tf w 0755} fd]} {
	fail "Cannot create zircon executable - \"$fd\""
	if {[file exists $tf.old]} {
	    file rename -force $tf.old $tf
	}
	return 0
    }
    puts $fd "#!$Wish"
    puts $fd "set zircon(lib) {$Lib}"
    puts $fd "#
proc zVersion {} {
    global zircon
    array set zircon {
	version		$Version
	patchlevel	$Patchlevel
    }
}
#"
    puts $fd [info body zircon]
    close $fd
    return 1}





